pub struct Error { /* private fields */ }Expand description
Errors from this crate related to parsing WAT files
An error can during example phases like:
- Lexing can fail if the document is syntactically invalid.
- A string may not be utf-8
- The syntactical structure of the wat file may be invalid
- The wat file may be semantically invalid such as having name resolution failures
Implementations